==> doctorlink-design-system-1.0.32.tgz: package/es/Components/Button/Button.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';

const primaryStyle = css`
  background-color: red;
  border-color: ${p => p.theme.button.primary.borderColor};
  color: ${p => p.theme.button.primary.color};
  &:hover {
    background-color: ${p => p.theme.button.primary.hover.backgroundColor};
    border-color: ${p => p.theme.button.primary.hover.borderColor};
    color: ${p => p.theme.button.primary.hover.color};
  }
  &:active {
    background-color: ${p => p.theme.button.primary.active.backgroundColor};
    border-color: ${p => p.theme.button.primary.active.borderColor};
    color: ${p => p.theme.button.primary.active.color};
  }
  &:disabled {
    background-color: ${p => p.theme.button.primary.disabled.backgroundColor};
    border-color: ${p => p.theme.button.primary.disabled.borderColor};
    color: ${p => p.theme.button.primary.disabled.color};
  }
`;

const standardStyle = css`
  background-color: ${p => p.theme.button.standard.backgroundColor};
  border-color: ${p => p.theme.button.standard.borderColor};
  color: ${p => p.theme.button.standard.color};
  &:hover {
    background-color: ${p => p.theme.button.standard.hover.backgroundColor};
    border-color: ${p => p.theme.button.standard.hover.borderColor};
    color: ${p => p.theme.button.standard.hover.color};
  }
  &:active {
    background-color: ${p => p.theme.button.standard.active.backgroundColor};
    border-color: ${p => p.theme.button.standard.active.borderColor};
    color: ${p => p.theme.button.standard.active.color};
  }
  &:disabled {
    background-color: ${p => p.theme.button.standard.disabled.backgroundColor};
    border-color: ${p => p.theme.button.standard.disabled.borderColor};
    color: ${p => p.theme.button.standard.disabled.color};
  }
`;
const themes = {
  standard: standardStyle,
  primary: primaryStyle
};

export const ButtonComponent = reset.button.attrs({
  noWrap: p => p.noWrap,
  variant: p => p.variant || 'standard'
})`
  outline: 0;
  cursor: pointer;
  border-radius: ${p => p.theme.button.base.borderRadius}px;
  font-size: ${p => p.theme.button.base.fontSize}px;
  line-height: ${p => p.theme.button.base.lineHeight}px;
  font-weight: ${p => p.theme.button.base.fontWeight};
  min-width: ${p => p.theme.button.base.minWidth};
  padding-top: ${p => p.theme.button.base.paddingTop};
  padding-bottom: ${p => p.theme.button.base.paddingBottom};
  padding-left: ${p => p.theme.button.base.paddingLeft};
  padding-right: ${p => p.theme.button.base.paddingRight};
  margin-top: ${p => p.theme.button.base.marginTop};
  margin-bottom: ${p => p.theme.button.base.marginBottom};
  border-width: ${p => p.theme.button.base.borderWidth};
  border-style: ${p => p.theme.button.base.borderStyle};
  ${p => themes[p.variant] || themes.standard}};
  ${p => !p.noWrap && noWrap};
`;

const Button = props => React.createElement(ButtonComponent, props);
// export const Anchor = Button.withComponent('a');

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the component to not wrap.
   */
  noWrap: PropTypes.bool,
  /**
   * The theme variant of the button
   */
  variant: PropTypes.oneOf(['standard', 'primary'])
} : {};

Button.defaultProps = {
  noWrap: true,
  variant: 'standard'
};

export default Button;

==> doctorlink-design-system-1.0.39.tgz: package/es/Components/Button/Button.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';

const primaryStyle = css`
  background-color: ${p => p.theme.button.primary.backgroundColor};
  border-color: ${p => p.theme.button.primary.borderColor};
  color: ${p => p.theme.button.primary.color};
  &:hover {
    background-color: ${p => p.theme.button.primary.hover.backgroundColor};
    border-color: ${p => p.theme.button.primary.hover.borderColor};
    color: ${p => p.theme.button.primary.hover.color};
  }
  &:active {
    background-color: ${p => p.theme.button.primary.active.backgroundColor};
    border-color: ${p => p.theme.button.primary.active.borderColor};
    color: ${p => p.theme.button.primary.active.color};
  }
  &:disabled {
    background-color: ${p => p.theme.button.primary.disabled.backgroundColor};
    border-color: ${p => p.theme.button.primary.disabled.borderColor};
    color: ${p => p.theme.button.primary.disabled.color};
  }
`;

const standardStyle = css`
  background-color: ${p => p.theme.button.standard.backgroundColor};
  border-color: ${p => p.theme.button.standard.borderColor};
  color: ${p => p.theme.button.standard.color};
  &:hover {
    background-color: ${p => p.theme.button.standard.hover.backgroundColor};
    border-color: ${p => p.theme.button.standard.hover.borderColor};
    color: ${p => p.theme.button.standard.hover.color};
  }
  &:active {
    background-color: ${p => p.theme.button.standard.active.backgroundColor};
    border-color: ${p => p.theme.button.standard.active.borderColor};
    color: ${p => p.theme.button.standard.active.color};
  }
  &:disabled {
    background-color: ${p => p.theme.button.standard.disabled.backgroundColor};
    border-color: ${p => p.theme.button.standard.disabled.borderColor};
    color: ${p => p.theme.button.standard.disabled.color};
  }
`;
const themes = {
  standard: standardStyle,
  primary: primaryStyle
};

export const ButtonComponent = reset.button.attrs({
  noWrap: p => p.noWrap,
  variant: p => p.variant || 'standard'
})`
  outline: 0;
  cursor: pointer;
  border-radius: ${p => p.theme.button.base.borderRadius}px;
  font-size: ${p => p.theme.button.base.fontSize}px;
  line-height: ${p => p.theme.button.base.lineHeight}px;
  font-weight: ${p => p.theme.button.base.fontWeight};
  min-width: ${p => p.theme.button.base.minWidth};
  padding-top: ${p => p.theme.button.base.paddingTop};
  padding-bottom: ${p => p.theme.button.base.paddingBottom};
  padding-left: ${p => p.theme.button.base.paddingLeft};
  padding-right: ${p => p.theme.button.base.paddingRight};
  margin-top: ${p => p.theme.button.base.marginTop};
  margin-bottom: ${p => p.theme.button.base.marginBottom};
  border-width: ${p => p.theme.button.base.borderWidth};
  border-style: ${p => p.theme.button.base.borderStyle};
  ${p => themes[p.variant] || themes.standard}};
  ${p => !p.noWrap && noWrap};
`;

const Button = props => React.createElement(ButtonComponent, props);
// export const Anchor = Button.withComponent('a');

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the component to not wrap.
   */
  noWrap: PropTypes.bool,
  /**
   * The theme variant of the button
   */
  variant: PropTypes.oneOf(['standard', 'primary'])
} : {};

Button.defaultProps = {
  noWrap: true,
  variant: 'standard'
};

export default Button;
